/*
 * Detect a Library for hardware detection
 *
 * Detect modification's are Copyright (C) 2005 Alexandre Dussart
 *
 * This part is based on GPL ddcprobe.c code.
 */




#include <sys/types.h>
#include <sys/stat.h>
#include <sys/syscall.h>
#include <sys/mman.h>
#include <assert.h>
#include <ctype.h>
#include <stdio.h>
#include <fcntl.h>
#include <string.h>
#include <unistd.h>
#include <stdlib.h>
#include <signal.h>
#include <netinet/in.h>
#include <sys/vm86.h>
#include <sys/io.h>

#include "detect.h"
#include "ddcprobe/vbe.h"
#include "ddcprobe/lrmi.h"

#include <byteswap.h>


char *snip(char *string)
{
	int i;
	
	string[12] = '\0';
	
	while(((i = strlen(string)) > 0) &&
	       (isspace(string[i - 1]) ||
	        (string[i - 1] == '\n') ||
	        (string[i - 1] == '\r'))) {
		string[i - 1] = '\0';
	}
	/*Fix to end the string*/
	string[i - 1] = '\0';
	return string;
}

struct monitor_info *monitor_detect()
{
 struct monitor_info *result = (struct monitor_info *)NULL;
 
  struct edid1_info *edid_info = NULL;
  int i;
  assert(sizeof(struct edid1_info) == 256);
  assert(sizeof(struct edid_detailed_timing) == 18);
  assert(sizeof(struct edid_monitor_descriptor) == 18);
  edid_info = get_edid_info();

    if (result)
	return result;


  if(debug)
    fprintf(stdout, "\nProbing monitor...\n");

/* Interpret results. */
  if((edid_info == NULL) || (edid_info->version == 0)) {
  fprintf(stdout, "EDID read failed. (No DDC-capable monitor attached?)\n");
  return NULL;
  }

  if ((edid_info->version == 0xff && edid_info->revision == 0xff)
    || (edid_info->version == 0 && edid_info->revision == 0))  {
  fprintf(stdout, "EDID read failed, returned empty data\n");
  return NULL;
  }	  
  
 result = (struct monitor_info *) my_malloc(sizeof(struct monitor_info));

 for(i = 0; i < 4; i++) {
	struct edid_monitor_descriptor *monitor = NULL;
	monitor = &edid_info->monitor_details.monitor_descriptor[i];

        if(monitor->type == edid_monitor_descriptor_name) {
	/*We don't know vendor name*/
	result->vendor= s_unknown;
	result->model = snip(monitor->data.string);
		if(debug){
       		fprintf(stdout, "\t\tFound %s %s\n", 
                result->vendor, result->model);
		}
	}  else if(monitor->type == edid_monitor_descriptor_range) {
	result->horizontal_min = monitor->data.range_data.horizontal_min;
	result->horizontal_max = monitor->data.range_data.horizontal_max;
	result->vertical_min = monitor->data.range_data.vertical_min;
	result->vertical_max = monitor->data.range_data.vertical_max;
	}
 }

 return result;
}
