/*
 * Detect a Library for hardware detection
 *
 * Copyrigth (C) 2005 Alexandre Dussart
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#include "detect.h"
#include "utils.h"


extern struct wireless_info *wireless_detect(struct bus_lst *bus){
  struct pci_info *pci = (struct pci_info *)NULL;
  struct pcmcia_info *pcmcia = (struct pcmcia_info *)NULL;
  struct usb_info *usb = (struct usb_info *)NULL;
  struct wireless_info *result = (struct wireless_info *)NULL;
  static struct wireless_info *first = (struct wireless_info *)NULL;
  
  if(first){
    return first;
  }/*endif*/
  
  if(debug)
    printf(_("\nProbing wireless card...\n"));

  /********************************************************************/
  /******************* PCI wireless CARD DETECTION ********************/
  /********************************************************************/
  if(debug)
    printf(_("\tProbing PCI wireless card...\n"));

  
  for(pci = bus->pci; pci; pci = pci->next){
    if(pci->type == WIRELESSCARD){
      if(!first){
        first = result = (struct wireless_info *) 
                                my_malloc(sizeof(struct wireless_info));
      }else{
        result->next = (struct wireless_info *) 
                                my_malloc(sizeof(struct wireless_info));
        result = result->next;
      }/*endif*/
      result->next = (struct wireless_info *)NULL;
      result->vendor = pci->vendor;
      result->model = pci->model;
      result->module = pci->modulename;
      result->long_id = pci->id;
      result->bus = PCI;
      if(debug)
	printf(_("\t\tFound %s %s\n"), 
	       result->vendor, result->model);
    }/*endif*/
  }/*next pci*/
  
  /********************************************************************/
  /****************** PCMCIA wireless CARD DETECTION ******************/
  /********************************************************************/
  if(debug)
    printf(_("\tProbing PCMCIA wireless card...\n"));

  for(pcmcia = bus->pcmcia; pcmcia; pcmcia = pcmcia->next){
    if(pcmcia->type == WIRELESSCARD){
      if(!first){
        first = result = (struct wireless_info *) 
                                my_malloc(sizeof(struct wireless_info));
      }else{
        result->next = (struct wireless_info *) 
                                my_malloc(sizeof(struct wireless_info));
          result = result->next;
      }/*endif*/
      result->next = (struct wireless_info *)NULL;

      result->vendor = pcmcia->vendor;
      result->model = pcmcia->model;
      result->module = pcmcia->modulename;
      result->long_id = pcmcia->id;	
      result->bus = PCMCIA;
      if(debug)
	printf(_("\t\tFound %s %s\n"), 
	       result->vendor, result->model);
    }/*endif*/
  }/*next pcmcia*/

  /********************************************************************/
  /****************** USB wireless CARD DETECTION *********************/
  /********************************************************************/
  if(debug)
    printf(_("\tProbing USB wireless card...\n"));

  for(usb = bus->usb; usb; usb = usb->next){
    if(usb->type == WIRELESSCARD){
      if(!first){
        first = result = (struct wireless_info *) 
                                my_malloc(sizeof(struct wireless_info));
      }else{
        result->next = (struct wireless_info *) 
                                my_malloc(sizeof(struct wireless_info));
          result = result->next;
      }/*endif*/
      result->next = (struct wireless_info *)NULL;

      result->vendor = usb->vendor;
      result->model = usb->model;
      result->module = usb->modulename;
      result->long_id = usb->id;	
      result->bus = USB;
      if(debug)
	printf(_("\t\tFound %s %s\n"), 
	       result->vendor, result->model);
    }/*endif*/
  }/*next usb*/


  
  return first;
}/*endfunc wireless_detect*/
